Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(605)

Unified Diff: net/http/http_network_transaction.h

Issue 1808001: Implement a 15 connection per proxy server limit. (Closed) Base URL: http://src.chromium.org/git/chromium.git
Patch Set: Remove extra newline. Created 10 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/http/http_network_transaction.h
diff --git a/net/http/http_network_transaction.h b/net/http/http_network_transaction.h
index eb6f06ee91e0708da919aee2d25c0486c74d37f1..3217facc51c67b257e46e06cb3298faecea21599 100644
--- a/net/http/http_network_transaction.h
+++ b/net/http/http_network_transaction.h
@@ -362,9 +362,9 @@ class HttpNetworkTransaction : public HttpTransaction {
// The next state in the state machine.
State next_state_;
- // The hostname and port of the peer. This is not necessarily the one
- // specified by the URL, due to Alternate-Protocol or proxies.
- HostPortPair peer_;
+ // The hostname and port of the endpoint. This is not necessarily the one
+ // specified by the URL, due to Alternate-Protocol or fixed testing ports.
+ HostPortPair endpoint_;
DISALLOW_COPY_AND_ASSIGN(HttpNetworkTransaction);
};

Powered by Google App Engine
This is Rietveld 408576698